==> iTop-3.2.0-2-14758.zip: web/dictionaries/ui/pages/preferences/ru.dictionary.itop.preferences.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('RU RU', 'Russian', 'Русский', [
	'UI:Favorites:General:ShowSummaryCards' => 'Show summary cards~~',
	'UI:Favorites:General:ShowSummaryCards+' => 'When hovering an hyperlink targeting an object, display a short summary of the object, if available for that class~~',
	'UI:Preferences:ActivityPanel:EntryFormOpened' => 'Форма записи журнала открыта по умолчанию',
	'UI:Preferences:ActivityPanel:EntryFormOpened+' => 'Состояние формы добавления записи журнала при отображении объекта. Если флажок снят, форму можно будет открыть с помощью соответствующей кнопки.',
	'UI:Preferences:ActivityPanel:Title' => 'Панель активности',
	'UI:Preferences:ChooseAPlaceholder' => 'Аватар пользователя',
	'UI:Preferences:ChooseAPlaceholder+' => 'Выберите аватар, который будет отображаться, если у связанного с вашей учетной записью контакта нет фотографии',
	'UI:Preferences:ChooseAPlaceholder:Success:Message' => 'Your placeholder image has been successfully updated~~',
	'UI:Preferences:General:Theme' => 'Тема',
	'UI:Preferences:General:Theme:DefaultThemeLabel' => '%1$s (по умолчанию)',
	'UI:Preferences:General:Title' => 'Основные',
	'UI:Preferences:General:Toasts' => 'Toast notifications position~~',
	'UI:Preferences:General:Toasts:Bottom' => 'Bottom~~',
	'UI:Preferences:General:Toasts:Top' => 'Top~~',
	'UI:Preferences:Lists:Title' => 'Списки',
	'UI:Preferences:Notifications' => 'Notifications~~',
	'UI:Preferences:Notifications+' => 'Configure the notifications you want to receive <a href="%1$s">on this page</a>.~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset' => 'Reset~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset:Tooltip' => 'Back to default keyboard shortcut~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Tooltip' => 'Записать сочетание клавиш',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Input:Hint' => 'Введите сочетание клавиш',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Title' => 'Сочетания клавиш',
	'UI:Preferences:RichText:Title' => 'Текстовый редактор',
	'UI:Preferences:RichText:ToolbarState' => 'Панель инструментов по умолчанию',
	'UI:Preferences:RichText:ToolbarState:Collapsed' => 'Свёрнута',
	'UI:Preferences:RichText:ToolbarState:Expanded' => 'Развёрнута',
	'UI:Preferences:Tabs:Layout:Horizontal' => 'Горизонтальное',
	'UI:Preferences:Tabs:Layout:Label' => 'Расположение',
	'UI:Preferences:Tabs:Layout:Vertical' => 'Вертикальное',
	'UI:Preferences:Tabs:Scrollable:Classic' => 'Классическая',
	'UI:Preferences:Tabs:Scrollable:Label' => 'Навигация',
	'UI:Preferences:Tabs:Scrollable:Scrollable' => 'Прокручиваемая',
	'UI:Preferences:Tabs:Title' => 'Вкладки',
	'UI:Preferences:Title' => 'Предпочтения',
	'UI:Preferences:UserInterface:Title' => 'Пользовательский интерфейс',
]);

==> iTop-3.2.2-1-17851.zip: web/dictionaries/ui/pages/preferences/ru.dictionary.itop.preferences.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('RU RU', 'Russian', 'Русский', array(
	'UI:Preferences:Title' => 'Предпочтения',
	'UI:Preferences:UserInterface:Title' => 'Пользовательский интерфейс',
	'UI:Preferences:General:Title' => 'Основные',
	'UI:Preferences:General:Theme' => 'Тема',
	'UI:Preferences:General:Theme:DefaultThemeLabel' => '%1$s (по умолчанию)',
	'UI:Favorites:General:ShowSummaryCards' => 'Show summary cards~~',
	'UI:Favorites:General:ShowSummaryCards+' => 'When hovering an hyperlink targeting an object, display a short summary of the object, if available for that class~~',
	'UI:Preferences:Lists:Title' => 'Списки',
	'UI:Preferences:RichText:Title' => 'Текстовый редактор',
	'UI:Preferences:RichText:ToolbarState' => 'Панель инструментов по умолчанию',
	'UI:Preferences:RichText:ToolbarState:Expanded' => 'Развёрнута',
	'UI:Preferences:RichText:ToolbarState:Collapsed' => 'Свёрнута',
	'UI:Preferences:ActivityPanel:Title' => 'Панель активности',
	'UI:Preferences:ActivityPanel:EntryFormOpened' => 'Форма записи журнала открыта по умолчанию',
	'UI:Preferences:ActivityPanel:EntryFormOpened+' => 'Состояние формы добавления записи журнала при отображении объекта. Если флажок снят, форму можно будет открыть с помощью соответствующей кнопки.',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Title' => 'Сочетания клавиш',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Input:Hint' => 'Введите сочетание клавиш',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Tooltip' => 'Записать сочетание клавиш',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset' => 'Reset~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset:Tooltip' => 'Back to default keyboard shortcut~~',
	'UI:Preferences:Tabs:Title' => 'Вкладки',
	'UI:Preferences:Tabs:Layout:Label' => 'Расположение',
	'UI:Preferences:Tabs:Layout:Horizontal' => 'Горизонтальное',
	'UI:Preferences:Tabs:Layout:Vertical' => 'Вертикальное',
	'UI:Preferences:Tabs:Scrollable:Label' => 'Навигация',
	'UI:Preferences:Tabs:Scrollable:Classic' => 'Классическая',
	'UI:Preferences:Tabs:Scrollable:Scrollable' => 'Прокручиваемая',
	'UI:Preferences:General:Toasts' => 'Toast notifications position~~',
	'UI:Preferences:General:Toasts:Bottom' => 'Bottom~~',
	'UI:Preferences:General:Toasts:Top' => 'Top~~',
	'UI:Preferences:ChooseAPlaceholder' => 'Аватар пользователя',
	'UI:Preferences:ChooseAPlaceholder+' => 'Выберите аватар, который будет отображаться, если у связанного с вашей учетной записью контакта нет фотографии',
	'UI:Preferences:ChooseAPlaceholder:Success:Message' => 'Your placeholder image has been successfully updated~~',
	'UI:Preferences:Notifications' => 'Notifications~~',
	'UI:Preferences:Notifications+' => 'Configure the notifications you want to receive <a href="%1$s">on this page</a>.~~',
	
));
